==> dl.php?src=linea21_1_1.zip: linea21/languages/fr/lang_publication.utf-8.php <==
<?php


// //////////////////////////////////////////////////
// Linea 21 - PHP language FR
// configuration des langues des modules
// create : 19/06/07
// last_modify : 20/06/07
// creative commons 2007 
//http://creativecommons.org/licenses/by-nc-sa/2.0/fr/legalcode
// //////////////////////////////////////////////////
/**
* lang_FR.php
* 
* @package linea21
* @author simon 
* @copyright Copyright (c) green-box 2003
* @version 1.0
* @access public 
*/



/*	nommage des modules
*  	*/
$lang['publication']['name']='dossier';
$lang['publication']['name2']='dossier(s)';
$lang['publication']['confirm_add'] = "Ajout du dossier réalisé avec succès\n";
$lang['publication']['confirm_mod'] = "Modification du dossier réalisée avec succès\n";
$lang['publication']['confirm_sup'] ="Suppression du dossier réalisée avec succès\n";


/*	nommage rubrique module
*  	*/
$lang['publication']['add']= 'Ajout d\'un '.$lang['publication']['name'];
$lang['publication']['mod']= 'Modification d\'un '.$lang['publication']['name'];
$lang['publication']['sup']= 'Suppression du '.$lang['publication']['name'];
$lang['publication']['det']= 'Détails du '.$lang['publication']['name'];
$lang['publication']['list']= 'Consultation des '.$lang['publication']['name'].'s';


/*	nommage public
*  	*/
$lang['publication']['next_part']='Voir la partie suivante ';
$lang['publication']['prev_part']='Voir la partie précédente ';
$lang['publication']['goto']='Aller à ';
/*	nommage rubrique add / mod /det
*  	*/
$lang['publication']['add_title']='Saisie des informations du nouveau '.$lang['publication']['name'];
$lang['publication']['mod_title']='Modification des informations du '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Dressant des états des lieux, fixant les enjeux et engageant des réflexions sur des cas concrets, les dossiers sauront parfaire vos connaissances en matière de développement durable.';

/*	check integrité des données
*  	*/
$lang['publication']['no_title'] = 'Il est nécessaire de donner un titre au nouveau dossier';
$lang['publication']['no_resume'] = 'Il est nécessaire d\'établir un resumé du dossier';
$lang['publication']['no_theme'] = 'Le dossier doit être rattaché à un thème';
$lang['publication']['no_scale'] = 'Le dossier doit être rattaché à une échelle';
$lang['publication']['no_level'] = 'Le dossier doit être rattaché à un niveau utilisateur';
$lang['publication']['no_author'] = 'Il est impératif de nommer un rédacteur de dossier';
$lang['publication']['author_not_valid'] = 'Le rédacteur choisi n\'existe pas ou son orthographe est erronée';
$lang['publication']['author_not_rights'] = 'Le rédacteur choisi n\'a pas les droits nécessaires';

/*	nommage élément rubrique
*  	*/
$lang['publication']['title']='titre';
$lang['publication']['resume']='resumé';
$lang['publication']['theme']='thème de rattachement';
$lang['publication']['level']='niveau de rattachement';
$lang['publication']['scale']='échelle de rattachement';
$lang['publication']['statut']='état de publication';
$lang['publication']['comment']='commentaire';

$lang['publication']['template']='modèle de présentation';
$lang['publication']['photouri']='visuel(s) associé(s)';
$lang['publication']['visu1']='visuel n°1';
$lang['publication']['visu2']='visuel n°2';
$lang['publication']['author']='rédacteur';
$lang['publication']['published_on']='date de publication';
$lang['publication']['not_published']='non publié';

$lang['publication']['generals']='Informations générales';
$lang['publication']['parts']='Détail du dossier';
$lang['publication']['listing']='Dossiers Linea21';
$lang['publication']['link_res']='Liens associés au dossier';
$lang['publication']['biblio_res']='Ressources bibliographiques';
$lang['publication']['multi_res']='Ressources Multimédia';



/*	nommage quickbox
*  	*/
$lang['publication']['qb_titleadd']=' derniers ajouts effectués';
$lang['publication']['qb_titlemod']=' dernières modifications effectuées';
$lang['publication']['qb_titlesup']=' dernières suppressions effectuées';
$lang['publication']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
*  	*/

$lang['publication']['nb_total']='dossiers sont repertoriés dans la base de données.';
$lang['publication']['statut_filter']='Afficher par statut';
$lang['publication']['part_number']='partie ';
$lang['publication']['part_number2']='Partie ';
$lang['publication']['description']='description';
$lang['publication']['all']='Afficher la liste complete';
$lang['publication']['noresult']='Aucun dossier ne correspond à ce critère de sélection ';
$lang['news']['template_1']='Texte + photo à gauche';
$lang['news']['template_2']='Texte + photo à droite';
$lang['news']['template_3']='Texte seulement';


/*	textes modules annexes
*  	*/
$lang['publication']['add_new_part']="Ajouter une nouvelle partie au dossier courant";
$lang['publication']['add_new_linkres']="Associer un nouveau lien au dossier courant";
$lang['publication']['add_new_multires']="Associer un nouveau document numérique au dossier courant";
$lang['publication']['add_new_bibliores']="Associer un nouvelle référence bibliographique au dossier courant";

$lang['publication']['no_link']="Aucun site n'est actuellement associé au dossier";
$lang['publication']['del_link']="Supprimer le lien";
$lang['publication']['mod_link']="Modifier le lien";

$lang['publication']['no_multi']="Aucun document multimédia n'est actuellement associé au dossier";
$lang['publication']['del_multi']="Supprimer le document numérique";
$lang['publication']['mod_multi']="Modifier le document numérique";

$lang['publication']['no_biblio']="Aucune référence bibliographique n'est actuellement associée au dossier";
$lang['publication']['del_biblio']="Supprimer la référence bibliographique";
$lang['publication']['mod_biblio']="Modifier la référence bibliographique";

$lang['publication']['no_part']="Actuellement, le dossier ne contient aucune partie";
$lang['publication']['del_part']="Supprimer la partie";
$lang['publication']['mod_part']="Modifier la partie";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='Pour ajouter un dossier, vous devez saisir  les informations requises dans le formulaire ci-dessus.';
$lang['publication']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['publication']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';

$lang['publication']['help_list1']='Pour afficher le détail d\'un dossier, cliquez sur le titre de celui-ci';
$lang['publication']['help_list2']='Vous pouvez supprimer un dossier en cliquant sur l\'icône de suppression qui lui est associée';
$lang['publication']['help_list3']='Vous pouvez modifier un dossier en cliquant sur l\'icône de modification qui lui est associée';
$lang['publication']['help_list4']='Vous pouvez utiliser le filtre \'par statut\' pour afficher les dossiers desirés';
$lang['publication']['help_list5']='Pour ajouter un dossier, cliquez sur le lien \'ajouter un dossier\' dans la barre de titre';


$lang['publication']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['publication']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['publication']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['publication']['help_det1']='Vous pouvez modifier les informations générales de ce dossier en cliquant sur l\'icône de modification qui lui est associée';
$lang['publication']['help_det2']='Vous pouvez supprimer ce dossier en cliquant sur l\'icône de suppression qui lui est associée';
$lang['publication']['help_det3']='Pour afficher les parties constituant le dossier, les liens associés, documents multimédias et ressources bibliographiques, cliquer sur afficher ces informations en bas de page';
$lang['publication']['help_det4']='Pour Ajouter-Modifier-Supprimer les parties constituant le dossier, les liens associés, documents multimédias et ressources bibliographiques, cliquer sur les icônes qui leur sont associées';

$lang['publication']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de ce dossier, cliquer sur \'Annuler\'';


?>

==> dl.php?src=linea21_1_3.zip: linea21/languages/fr/lang_publication.utf-8.php <==
<?php
/**
 * @package linea21.languages
 * @subpackage fr
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */


$lang['publication']['section'] = "dossiers";


/*	nommage des modules
*  	*/
$lang['publication']['name']='dossier';
$lang['publication']['name2']='dossier(s)';
$lang['publication']['confirm_add'] = "Ajout du dossier réalisé avec succès\n";
$lang['publication']['confirm_mod'] = "Modification du dossier réalisée avec succès\n";
$lang['publication']['confirm_sup'] ="Suppression du dossier réalisée avec succès\n";


/*	nommage rubrique module
*  	*/
$lang['publication']['add']= 'Ajout d\'un '.$lang['publication']['name'];
$lang['publication']['mod']= 'Modification d\'un '.$lang['publication']['name'];
$lang['publication']['sup']= 'Suppression du '.$lang['publication']['name'];
$lang['publication']['det']= 'Détails du '.$lang['publication']['name'];
$lang['publication']['list']= 'Consultation des publications';


/*	nommage public
*  	*/
$lang['publication']['next_part']='Voir la partie suivante ';
$lang['publication']['prev_part']='Voir la partie précédente ';
$lang['publication']['goto']='Aller à ';
/*	nommage rubrique add / mod /det
*  	*/
$lang['publication']['add_title']='Saisie des informations du nouveau '.$lang['publication']['name'];
$lang['publication']['mod_title']='Modification des informations du '.$lang['publication']['name'];

$lang['publication']['h1_public_comment']='Dressant des états des lieux, fixant les enjeux et engageant des réflexions sur des cas concrets, les dossiers sauront parfaire vos connaissances en matière de développement durable.';

/*	check integrité des données
*  	*/
$lang['publication']['no_title'] = 'Il est nécessaire de donner un titre au nouveau dossier';
$lang['publication']['no_resume'] = 'Il est nécessaire d\'établir un resumé du dossier';
$lang['publication']['no_theme'] = 'Le dossier doit être rattaché à un thème';
$lang['publication']['no_scale'] = 'Le dossier doit être rattaché à une échelle';
$lang['publication']['no_level'] = 'Le dossier doit être rattaché à un niveau utilisateur';
$lang['publication']['no_author'] = 'Il est impératif de nommer un rédacteur de dossier';
$lang['publication']['author_not_valid'] = 'Le rédacteur choisi n\'existe pas ou son orthographe est erronée';
$lang['publication']['author_not_rights'] = 'Le rédacteur choisi n\'a pas les droits nécessaires';

/*	nommage élément rubrique
*  	*/
$lang['publication']['title']='titre';
$lang['publication']['resume']='resumé';
$lang['publication']['theme']='thème de rattachement';
$lang['publication']['level']='niveau de rattachement';
$lang['publication']['scale']='échelle de rattachement';
$lang['publication']['statut']='état de publication';
$lang['publication']['comment']='commentaire';

$lang['publication']['template']='modèle de présentation';
$lang['publication']['photouri']='visuel(s) associé(s)';
$lang['publication']['visu1']='visuel n°1';
$lang['publication']['visu2']='visuel n°2';
$lang['publication']['author']='rédacteur';
$lang['publication']['published_on']='date de publication';
$lang['publication']['not_published']='non publié';

$lang['publication']['generals']='Informations générales';
$lang['publication']['parts']='Détail du dossier';
$lang['publication']['listing']='Dossiers Linea21';
$lang['publication']['link_res']='Liens associés au dossier';
$lang['publication']['biblio_res']='Ressources bibliographiques';
$lang['publication']['multi_res']='Ressources Multimédia';



/*	nommage quickbox
*  	*/
$lang['publication']['qb_titleadd']=' derniers ajouts effectués';
$lang['publication']['qb_titlemod']=' dernières modifications effectuées';
$lang['publication']['qb_titlesup']=' dernières suppressions effectuées';
$lang['publication']['qb_titlepubli']=' dernières publications effectuées';


/*	divers
*  	*/

$lang['publication']['nb_total']='dossiers sont repertoriés dans la base de données.';
$lang['publication']['statut_filter']='Afficher par statut';
$lang['publication']['part_number']='partie ';
$lang['publication']['part_number2']='Partie ';
$lang['publication']['description']='description';
$lang['publication']['all']='Afficher la liste complete';
$lang['publication']['noresult']='Aucun dossier ne correspond à ce critère de sélection ';
$lang['news']['template_1']='Texte + photo à gauche';
$lang['news']['template_2']='Texte + photo à droite';
$lang['news']['template_3']='Texte seulement';


/*	textes modules annexes
*  	*/
$lang['publication']['add_new_part']="Ajouter une nouvelle partie au dossier courant";
$lang['publication']['add_new_linkres']="Associer un nouveau lien au dossier courant";
$lang['publication']['add_new_multires']="Associer un nouveau document numérique au dossier courant";
$lang['publication']['add_new_bibliores']="Associer un nouvelle référence bibliographique au dossier courant";

$lang['publication']['no_link']="Aucun site n'est actuellement associé au dossier";
$lang['publication']['del_link']="Supprimer le lien";
$lang['publication']['mod_link']="Modifier le lien";

$lang['publication']['no_multi']="Aucun document multimédia n'est actuellement associé au dossier";
$lang['publication']['del_multi']="Supprimer le document numérique";
$lang['publication']['mod_multi']="Modifier le document numérique";

$lang['publication']['no_biblio']="Aucune référence bibliographique n'est actuellement associée au dossier";
$lang['publication']['del_biblio']="Supprimer la référence bibliographique";
$lang['publication']['mod_biblio']="Modifier la référence bibliographique";

$lang['publication']['no_part']="Actuellement, le dossier ne contient aucune partie";
$lang['publication']['del_part']="Supprimer la partie";
$lang['publication']['mod_part']="Modifier la partie";






/*	rubrique d'aide

*  	*/
$lang['publication']['help_add1']='Pour ajouter un dossier, vous devez saisir  les informations requises dans le formulaire ci-dessus.';
$lang['publication']['help_add2']='Après avoir validé le formulaire d\'ajout, vérifiez vos données dans le récapitulatif';
$lang['publication']['help_add3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';

$lang['publication']['help_list1']='Pour afficher le détail d\'un dossier, cliquez sur le titre de celui-ci';
$lang['publication']['help_list2']='Vous pouvez supprimer un dossier en cliquant sur l\'icône de suppression qui lui est associée';
$lang['publication']['help_list3']='Vous pouvez modifier un dossier en cliquant sur l\'icône de modification qui lui est associée';
$lang['publication']['help_list4']='Vous pouvez utiliser le filtre \'par statut\' pour afficher les dossiers desirés';
$lang['publication']['help_list5']='Pour ajouter un dossier, cliquez sur le lien \'ajouter un dossier\' dans la barre de titre';


$lang['publication']['help_mod1']='Vous pouvez modifier l\'ensemble des champs qui vous sont accessibles dans le formulaire ci-dessus';
$lang['publication']['help_mod2']='Après avoir validé le formulaire de modification, vérifiez les informations entrées dans le récapitulatif';
$lang['publication']['help_mod3']='Si le récapitulatif ne vous convient pas, vous pouvez cliquer sur \'revoir les paramètres\' pour modifier à nouveau les données';


$lang['publication']['help_det1']='Vous pouvez modifier les informations générales de ce dossier en cliquant sur l\'icône de modification qui lui est associée';
$lang['publication']['help_det2']='Vous pouvez supprimer ce dossier en cliquant sur l\'icône de suppression qui lui est associée';
$lang['publication']['help_det3']='Pour afficher les parties constituant le dossier, les liens associés, documents multimédias et ressources bibliographiques, cliquer sur afficher ces informations en bas de page';
$lang['publication']['help_det4']='Pour Ajouter-Modifier-Supprimer les parties constituant le dossier, les liens associés, documents multimédias et ressources bibliographiques, cliquer sur les icônes qui leur sont associées';

$lang['publication']['help_sup1']='Si vous ne souhaitez pas confirmer la suppression de ce dossier, cliquer sur \'Annuler\'';


?>
